==> HostCMS.Free_6.7.tar.gz: modules/shop/group/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Группы товаров',
	'links_groups' => "Группа",
	'links_groups_add' => "Добавить",
	'name' => "<acronym title=\"Название группы товаров\">Название группы</acronym>",
	'description' => "<acronym title=\"Описание группы товаров\">Описание группы</acronym>",
	'image_large' => "<acronym title=\"Изображение для группы товаров\">Изображение группы</acronym>",
	'image_small' => "<acronym title=\"Малое изображение для группы товаров\">Малое изображение</acronym>",
	'sorting' => "<acronym title=\"Порядок сортировки групп\">Порядок сортировки</acronym>",
	'indexing' => "<acronym title=\"Разрешить индексация групп модулем поиска по сайту\">Индексировать группу</acronym>",
	'active' => "<acronym title=\"Статус активности группы магазина\">Активность</acronym>",
	'path' => "<acronym title=\"Путь, например group_30312\">Путь</acronym>",
	'seo_title' => "<acronym title=\"Значение мета-тега title для группы товаров\">Заголовок (title)</acronym>",
	'seo_description' => "<acronym title=\"Значение мета-тега description для группы товаров\">Описание (description)</acronym>",
	'seo_keywords' => "<acronym title=\"Значение мета-тега keywords для группы товаров\">Ключевые слова (keywords)</acronym>",
	'guid' => '<acronym title="Идентификатор группы товаров для формата CommerceML, например ID00006831">Идентификатор группы товаров CommerceML</acronym>',
	'siteuser_id' => 'Пользователь сайта',
	'groups_add_form_title' => "Добавление информации о группе товаров",
	'groups_edit_form_title' => "Редактирование информации о группе товаров",
	'tab_yandex_market' => 'Экспорт/Импорт',
	'tab_group_description' => 'Описание',
	'tab_group_seo' => 'SEO',
	'parent_id' => '<acronym title="Группа, которой принадлежит группа">Группа</acronym>',
	'exec_typograph_for_description' => '<acronym title="Применить типографирование к описанию">Типографировать описание</acronym>',
	'use_trailing_punctuation_for_text' => '<acronym title="Оптическое выравнивание текста перемещает символы пунктуации за границу набора">Оптическое выравнивание</acronym>',
	'id' => "Идентификатор",
	'shop_id' => "Идентификатор магазина",
	'edit_success' => "Группа товаров успешно добавлена!",
	'copy_success' => "Группа товаров успешно скопирована!",
	'markDeleted_success' => "Группа товаров успешно удалена!",
	'changeActive_success' => "Информация успешно изменена",
	'properties' => "Свойства групп",
	'list_of_property_for_group' => "Список свойств групп товаров",
	'tab_properties' => "Дополнительные свойства",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'error_URL_shop_group' => 'В группе уже существует подгруппа с таким URL!',
	'error_URL_isset_item' => 'В группе существует товар с названием в URL, совпадающим с URL добавляемой/редактируемой подгруппы!',
	'apply_success' => "Информация успешно изменена",
	'move_success' => 'Группы товаров перенесены',
	'items_catalog_image' => "<acronym title=\"Изображение группы\">Изображение группы</acronym>",
	'items_catalog_image_small' => "<acronym title=\"Малое изображение группы\">Малое изображение группы</acronym>",
	'tab_seo_templates' => 'Шаблоны SEO',
	'seo_group_header' => 'Шаблоны групп',
	'seo_item_header' => 'Шаблоны товаров',
	'seo_group_title_template' => 'Шаблон title',
	'seo_group_description_template' => 'Шаблон description',
	'seo_group_keywords_template' => 'Шаблон keywords',
	'seo_item_title_template' => 'Шаблон title',
	'seo_item_description_template' => 'Шаблон description',
	'seo_item_keywords_template' => 'Шаблон keywords',
	'markDeleted' => 'Удалить группу',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/group/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Группы товаров',
	'links_groups' => "Группа",
	'links_groups_add' => "Добавить",
	'name' => "Название группы",
	'description' => "Описание группы",
	'image_large' => "Изображение группы",
	'image_small' => "Малое изображение",
	'sorting' => "Порядок сортировки",
	'indexing' => "Индексировать группу",
	'active' => "Активность",
	'path' => "<acronym title=\"Путь, например group_30312\">Путь</acronym>",
	'seo_title' => "Заголовок (title)",
	'seo_description' => "Описание (description)",
	'seo_keywords' => "Ключевые слова (keywords)",
	'guid' => '<acronym title="Идентификатор группы товаров для формата CommerceML, например ID00006831">Идентификатор группы товаров CommerceML</acronym>',
	'siteuser_id' => 'Клиент',
	'groups_add_form_title' => "Добавление информации о группе товаров",
	'groups_edit_form_title' => 'Редактирование информации о группе товаров "%s"',
	'tab_yandex_market' => 'Экспорт/Импорт',
	'tab_group_description' => 'Описание',
	'tab_group_seo' => 'SEO',
	'parent_id' => 'Группа',
	'exec_typograph_for_description' => 'Типографировать описание',
	'use_trailing_punctuation_for_text' => '<acronym title="Оптическое выравнивание текста перемещает символы пунктуации за границу набора">Оптическое выравнивание</acronym>',
	'id' => "Идентификатор",
	'shop_id' => "Идентификатор магазина",
	'edit_success' => "Группа товаров успешно добавлена!",
	'copy_success' => "Группа товаров успешно скопирована!",
	'markDeleted_success' => "Группа товаров успешно удалена!",
	'changeActive_success' => "Информация успешно изменена",
	'properties' => "Свойства групп",
	'list_of_property_for_group' => "Список свойств групп товаров",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'error_URL_shop_group' => 'В группе уже существует подгруппа с таким URL!',
	'error_URL_isset_item' => 'В группе существует товар с названием в URL, совпадающим с URL добавляемой/редактируемой подгруппы!',
	'apply_success' => "Информация успешно изменена",
	'move_success' => 'Группы товаров перенесены',
	'items_catalog_image' => "Изображение группы",
	'items_catalog_image_small' => "Малое изображение группы",
	'tab_seo_templates' => 'Шаблоны SEO',
	'seo_group_header' => 'Шаблоны групп',
	'seo_item_header' => 'Шаблоны товаров',
	'seo_group_title_template' => 'Шаблон title',
	'seo_group_description_template' => 'Шаблон description',
	'seo_group_keywords_template' => 'Шаблон keywords',
	'seo_group_h1_template' => 'Шаблон H1',
	'seo_item_title_template' => 'Шаблон title',
	'seo_item_description_template' => 'Шаблон description',
	'seo_item_keywords_template' => 'Шаблон keywords',
	'seo_item_h1_template' => 'Шаблон H1',
	'markDeleted' => 'Удалить группу',
	'shortcut_success' => "Ярлык группы успешно добавлен",
	'change_attributes_success' => 'Атрибуты изменены успешно!',
	'items_total_count' => 'Количество активных товаров'
);
